@@ -20,6 +20,9 @@ from typing import Optional
 import torch
 import torch.utils
 
+from slidingpuzzle.heuristics import Heuristic
+from slidingpuzzle.nn.dataset import SlidingPuzzleDataset
+
 
 def accuracy(expected, predicted) -> float:
     r"""
@@ -30,12 +33,17 @@ def accuracy(expected, predicted) -> float:
 
         f(e, p) = 1 - \frac{|e - p|}{1 + |e - p|}
 
+    It returns the sum along the batch dimension.
+
+    Notes:
+        Any NaNs/infs will be replaced by 0.
+
     Args:
         expected: A tensor with the expected value
         predicted: A tensor with the predicted value
 
     Returns:
-        The accuracy as a float in the range [0, 1].
+        The accuracy as a float in the range [0, 1] summed along batch dim.
     """
     diff = torch.abs(expected - predicted)
     diff /= 1 + diff
@@ -63,7 +71,7 @@ def evaluate(
     running_loss = 0.0
     running_accuracy = 0.0
     dataloader = torch.utils.data.DataLoader(dataset)
-    with torch.no_grad():
+    with torch.inference_mode():
         for batch, expected in iter(dataloader):
             predicted = model(batch.to(device))
             expected = expected.to(device)
@@ -99,3 +107,15 @@ def eval_checkpoint(
         return evaluate_(
             model.h, model.h, weuristic=heuristic, num_iters=num_iters, **kwargs
         )
+
+
+def eval_heuristic(dataset: SlidingPuzzleDataset, heuristic: Heuristic) -> float:
+    r"""
+    Runs all examples through heuristic and evaluates accuracy as a function of
+    heuristic proximity to the true distance. Can be used to compare model performance
+    against other heuristics.
+    """
+    acc = 0.0
+    for x, y in dataset:
+        acc += accuracy(y, heuristic(x.numpy()))
+    return acc / len(dataset)
