@@ -32,10 +32,11 @@ def get_heuristic_key(h: int, w: int, version: str):
 
 
 def make_heuristic(model: torch.nn.Module | torch.ScriptModule):
-    device = "cuda" if torch.cuda.is_available() else "cpu"
+    device = models.DEVICE
+    dtype = models.DTYPE
 
     def heuristic(board: tuple[list[int], ...]) -> float:
-        tensor = torch.tensor(board, dtype=torch.float32).unsqueeze(0).to(device)
+        tensor = torch.tensor(board, dtype=dtype).unsqueeze(0).to(device)
         return model(tensor).item()
 
     return heuristic
@@ -78,3 +79,18 @@ def v1_distance(board: Board) -> float:
     h, w = len(board), len(board[0])
     heuristic = get_heuristic(h, w, models.VERSION_1)
     return heuristic(board)
+
+
+def v2_distance(board: Board) -> float:
+    """
+    A neural network that estimates distance to goal
+
+    Args:
+        board: The board
+
+    Returns:
+        An estimated number of moves to reach the goal
+    """
+    h, w = len(board), len(board[0])
+    heuristic = get_heuristic(h, w, models.VERSION_2)
+    return heuristic(board)
